@@ -2,6 +2,7 @@
 
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
+from __future__ import annotations
 
 import logging
 import sys
@@ -51,7 +52,7 @@ class InProcessKernel(IPythonKernel):
     _underlying_iopub_socket = Instance(DummySocket, ())
     iopub_thread: IOPubThread = Instance(IOPubThread)  # type:ignore[assignment]
 
-    shell_stream = Instance(DummySocket, ())  # type:ignore[arg-type]
+    shell_stream = Instance(DummySocket, ())  # type:ignore[assignment]
 
     @default("iopub_thread")
     def _default_iopub_thread(self):
@@ -65,7 +66,7 @@ class InProcessKernel(IPythonKernel):
     def _default_iopub_socket(self):
         return self.iopub_thread.background_socket
 
-    stdin_socket = Instance(DummySocket, ())  # type:ignore[assignment]
+    stdin_socket = Instance(DummySocket, ())
 
     def __init__(self, **traits):
         """Initialize the kernel."""
@@ -85,17 +86,16 @@ class InProcessKernel(IPythonKernel):
         if self.shell:
             self.shell.exit_now = False
 
-    def _abort_queues(self):
+    def _abort_queues(self, subshell_id: str | None = ...):
         """The in-process kernel doesn't abort requests."""
 
-    async def _flush_control_queue(self):
-        """No need to flush control queues for in-process"""
-
     def _input_request(self, prompt, ident, parent, password=False):
         # Flush output before making the request.
         self.raw_input_str = None
-        sys.stderr.flush()
-        sys.stdout.flush()
+        if sys.stdout is not None:
+            sys.stdout.flush()
+        if sys.stderr is not None:
+            sys.stderr.flush()
 
         # Send the input request.
         content = json_clean(dict(prompt=prompt, password=password))
@@ -135,7 +135,7 @@ class InProcessKernel(IPythonKernel):
         """Called when a message is sent to the IO socket."""
         assert self.iopub_socket.io_thread is not None
         assert self.session is not None
-        ident, msg = self.session.recv(self.iopub_socket.io_thread.socket, copy=False)
+        _ident, msg = self.session.recv(self.iopub_socket.io_thread.socket, copy=False)
         for frontend in self.frontends:
             assert frontend is not None
             frontend.iopub_channel.call_handlers(msg)
@@ -193,11 +193,11 @@ class InProcessInteractiveShell(ZMQInteractiveShell):
             gui = self.kernel.gui
         return super().enable_matplotlib(gui)
 
-    def enable_pylab(self, gui=None, import_all=True, welcome_message=False):
+    def enable_pylab(self, gui=None, import_all=True):
         """Activate pylab support at runtime."""
         if not gui:
             gui = self.kernel.gui
-        return super().enable_pylab(gui, import_all, welcome_message)
+        return super().enable_pylab(gui, import_all)
 
 
 InteractiveShellABC.register(InProcessInteractiveShell)
